@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.16.1+1" },
-            { "jdk", "11.0.16.1" },
-            { "release", "11.0.16.1" },
+            { "full", "11.0.17+1" },
+            { "jdk", "11.0.17" },
+            { "release", "11.0.17" },
         };
     }
 }
